/*
 * file CcBranchType.java
 *
 *
 * Licensed Materials - Property of IBM 
 * Restricted Materials of IBM  
 * 
 * com.ibm.rational.wvcm.stp.cc.CcBranchType
 * 
 *  Copyright IBM Corporation 2004, 2009.  All Rights Reserved. 
 * Note to U.S. Government Users Restricted Rights:  Use, duplication or  
 * disclosure restricted by GSA ADP  Schedule Contract with IBM Corp. 
 */


package com.ibm.rational.wvcm.stp.cc;

import javax.wvcm.Feedback;
import javax.wvcm.WvcmException;

/**
 * <p>
 * A proxy for a ClearCase branch type.
 * </p>
 * <p>
 * Branches are used in base ClearCase to enable parallel development. 
 * A branch is an object that specifies a linear sequence of versions of an element. 
 * Every element has one <b>main</b> branch, which represents the principal line of development, 
 * and may have multiple subbranches, each of which represents a separate line of development. 
 * For example, a project team may use the <b>main</b> branch for new development work while using a 
 * subbranch simultaneously for fixing a bug.
 * </p>
 * <p>
 * For more branch information, see the ClearCase "Guide to Managing Software Projects"
 * manual, and the cleartool man pages "mkbrtype" and "mkbranch".
 * </p>
 */
public interface CcBranchType extends CcTypeBase
{
    /**
     * <p>Create a new branch type at the location identified by this proxy. The
     * location should be an object name selector specifying the branch type's name
     * and the repository (VOB) in which to create it.
     * </p>
     * <p>Set the {@link CcTypeBase#SCOPE} property to specify the new type's global scope.
     * If no scope is set, a scope of NONE (ordinary scope) is used.
     * </p>
     * <p>Set the {@link CcTypeBase#INSTANCE_CONSTRAINT} property to determine where the new type
     * may be applied.  Valid values for branch types are BRANCH and ELEMENT.  If no constraint
     * is set the default is ELEMENT.
     * </p>
     * @param flags Resource-specific creation flags.
     */
    public CcBranchType doCreateCcBranchType(TypeCreateFlag[] flags, Feedback feedback) throws WvcmException;
}
